require 'faraday'
require 'json'

module Progimage
  class Client
    class << self
      API_ENDPOINT = 'https://kdkkxodzvg.execute-api.eu-west-2.amazonaws.com/prod'.freeze

      def fetch_image(id)
        request(
          http_method: :get,
          endpoint: "images/#{id}"
        )
      end

      def upload_image(file)
        request(
          http_method: :post,
          endpoint: "images",
          params: {
            file: file,
          }
        )
      end

      def transform_image(id, specs = {})
        request(
          http_method: :post,
          endpoint: "images/#{id}/transform",
          params: {
            specs: specs,
          }
        )
      end

      private

      def client
        @_client ||= Faraday.new(url: API_ENDPOINT) do |client|
          client.request :url_encoded
          client.adapter Faraday.default_adapter
        end
      end

      def request(http_method:, endpoint:, params: {})
        response = client.public_send(http_method, endpoint, params)
        JSON.parse(response.body)
      end
    end
  end
end
